@@ -18,13 +18,19 @@ use Term::ReadKey 'ReadMode';
 
 sub prompt {
     my $msg = shift;
-    chomp $msg;
-    STDOUT->printflush($msg);
-    local $SIG{INT} = sub { ReadMode 'restore', \*STDIN; STDOUT->printflush("\n"); exit };
+    local $| = 1;
+    print $msg;
     ReadMode 'noecho', \*STDIN;
-    my $answer = <STDIN>;
+    my $SIGNAL = "catch signal INT\n";
+    my $answer;
+    eval {
+        local $SIG{INT} = sub { die $SIGNAL };
+        $answer = <STDIN>;
+    };
+    my $error = $@;
     ReadMode 'restore', \*STDIN;
-    STDOUT->printflush("\n");
+    print "\n";
+    die $error if $error;
     chomp $answer;
     $answer;
 }
@@ -35,7 +41,7 @@ my $SUDO_PROMPT = sprintf "sudo password (asking with %s): ", basename($0);
 
 STDOUT->autoflush(1);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     my $class = shift;
@@ -250,7 +256,7 @@ sub parse_options {
     };
     GetOptions
         "c|concurrency=i"     => \($self->{concurrency} = 5),
-        "h|help"              => sub { pod2usage(0) },
+        "h|help"              => sub { pod2usage(verbose => 99, sections => 'SYNOPSIS|OPTIONS|EXAMPLES') },
         "u|user=s"            => sub { $deprecated->("user"); $self->{user} = $_[1] },
         "i|identity=s"        => sub { $deprecated->("identity"); $self->{identity} = $_[1] },
         "s|script=s"          => \($self->{script}),
@@ -313,6 +319,12 @@ App::RemoteCommand - simple remote command launcher via ssh
 
 =head1 DESCRIPTION
 
+=begin html
+
+<a href="https://asciinema.org/a/119109?autoplay=1" target="_blank"><img src="https://asciinema.org/a/119109.png" alto="usage" /></a>
+
+=end html
+
 App::RemoteCommand is a simple remote command launcher via ssh. The features are:
 
 =over 4
